@@ -1,6 +1,6 @@
 // Ceres Solver - A fast non-linear least squares minimizer
-// Copyright 2010, 2011, 2012 Google Inc. All rights reserved.
-// http://code.google.com/p/ceres-solver/
+// Copyright 2015 Google Inc. All rights reserved.
+// http://ceres-solver.org/
 //
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
@@ -78,7 +78,7 @@ class CanonicalViewsTest : public ::testing::Test {
   WeightedGraph<int> graph_;
 
   CanonicalViewsClusteringOptions options_;
-  vector<int> centers_;
+  std::vector<int> centers_;
   HashMap<int, int> membership_;
 };
 
